@@ -2,10 +2,15 @@ import os
 from unittest import mock
 
 from streamingcli.config import DEFAULT_PROFILE_PATH, PROFILE_ENV_VARIABLE_NAME
-from streamingcli.profile.profile_adapter import ProfileAdapter, ScliProfile
+from streamingcli.profile.profile_adapter import (
+    DeploymentMode,
+    ProfileAdapter,
+    ScliProfile,
+)
 
-TEST_PROFILE = ScliProfile(
+VVP_TEST_PROFILE = ScliProfile(
     profile_name="test_profile",
+    deployment_mode=DeploymentMode.VVP,
     ververica_url="ververica_url",
     ververica_namespace="ververica_namespace",
     docker_registry_url="docker_registry_url",
@@ -25,20 +30,21 @@ class TestProfileAdapter:
     """Test creating and managing profiles"""
 
     def test_create_new_profile(self):
-        ProfileAdapter.save_profile(TEST_PROFILE)
+        ProfileAdapter.save_profile(VVP_TEST_PROFILE)
         assert os.path.isfile(DEFAULT_PROFILE_PATH) is True
 
         saved_profile = ProfileAdapter.get_profile(
-            profile_name=TEST_PROFILE.profile_name
+            profile_name=VVP_TEST_PROFILE.profile_name
         )
-        assert saved_profile.profile_name == TEST_PROFILE.profile_name
-        assert saved_profile.ververica_url == TEST_PROFILE.ververica_url
-        assert saved_profile.ververica_namespace == TEST_PROFILE.ververica_namespace
-        assert saved_profile.docker_registry_url == TEST_PROFILE.docker_registry_url
-        assert saved_profile.ververica_api_token == TEST_PROFILE.ververica_api_token
+        assert saved_profile.profile_name == VVP_TEST_PROFILE.profile_name
+        assert saved_profile.ververica_url == VVP_TEST_PROFILE.ververica_url
+        assert saved_profile.ververica_namespace == VVP_TEST_PROFILE.ververica_namespace
+        assert saved_profile.docker_registry_url == VVP_TEST_PROFILE.docker_registry_url
+        assert saved_profile.ververica_api_token == VVP_TEST_PROFILE.ververica_api_token
+        assert saved_profile.k8s_namespace is None
         assert (
             saved_profile.ververica_deployment_target
-            == TEST_PROFILE.ververica_deployment_target
+            == VVP_TEST_PROFILE.ververica_deployment_target
         )
 
     """Test updating profile data"""
@@ -46,18 +52,14 @@ class TestProfileAdapter:
     def test_updating_profile_data(self):
         updated_ververica_url = "updated_ververica_url"
         updated_profile = ProfileAdapter.update_profile_data(
-            TEST_PROFILE, ververica_url=updated_ververica_url
+            VVP_TEST_PROFILE, ververica_url=updated_ververica_url
         )
         assert updated_profile.ververica_url == updated_ververica_url
-        assert (
-            updated_profile.ververica_deployment_target
-            == TEST_PROFILE.ververica_deployment_target
-        )
 
     """Test creating temporary profile"""
 
     def test_getting_temporary_profile(self):
-        ProfileAdapter.save_profile(TEST_PROFILE)
+        ProfileAdapter.save_profile(VVP_TEST_PROFILE)
         empty_profile = ProfileAdapter.load_profiles(default_profile_path="~/aaa.json")
         assert len(empty_profile.profiles) == 0
 
